# Phoenix4All

[![Release](https://img.shields.io/github/v/release/taurex-space/phoenix4all)](https://img.shields.io/github/v/release/taurex-space/phoenix4all)
[![Build status](https://img.shields.io/github/actions/workflow/status/taurex-space/phoenix4all/main.yml?branch=main)](https://github.com/taurex-space/phoenix4all/actions/workflows/main.yml?query=branch%3Amain)
[![Commit activity](https://img.shields.io/github/commit-activity/m/taurex-space/phoenix4all)](https://img.shields.io/github/commit-activity/m/taurex-space/phoenix4all)
[![License](https://img.shields.io/github/license/taurex-space/phoenix4all)](https://img.shields.io/github/license/taurex-space/phoenix4all)

All in one library for loading and using phoenix spectra
